umling
======

Installation
------------

$ pip install umling

Documentation
-------------

Visit <https://umling.readthedocs.io/en/latest/index.html>

Terms of use
------------

See the LICENSE file.
